#
# This file is part of "Cut the Crap" (CTC) filtering proxy server.
# Copyright 1999 Constantinos A. Kotsokalis <ckotso@cs.ntua.gr>
#
# CTC is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# CTC is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with CTC; see the file COPYING. If not, write to the
# Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#

import sys
import os
import posixpath
import read_conf
import zaplet_engine
import socket

# Define some default startup values -- these are overrided by 
# configuration file settings.
def startup_values():

	cfg = {}
	cfg['BIND_PORT'] = 5050
	cfg['PARENT_PROXY_HOST'] = ''
	cfg['PARENT_PROXY_PORT'] = 8080
	cfg['RETURN_GIF'] = "/usr/local/lib/ctc/white.gif"
	cfg['CTC_GIF'] = "/usr/local/lib/ctc/ctc.gif"
	cfg['ERROR_HTML_FILE'] = "/usr/local/lib/ctc/ctc_error.html"
	cfg['ZAPLET_DIR'] = "/usr/local/lib/ctc/zaplets"

	return cfg


# Exchange GIF file paths with GIFs into configuration dictionary,
# to make things a bit faster (well, memory intensive too). This function
# also replaces HTML file paths with HTML files (currently only the
# error file), and it defines some return headers too.
def cfg_convert(cfg):

	tmpval = os.stat(cfg['RETURN_GIF'])
	RETURN_GIF_SIZE = tmpval[6]
	locf = open(cfg['RETURN_GIF'], 'r')
	cfg['RETGIF'] = locf.read(RETURN_GIF_SIZE)
	locf.close()
	del cfg['RETURN_GIF']

	tmpval = os.stat(cfg['CTC_GIF'])
	CTC_GIF_SIZE = tmpval[6]
	locf = open(cfg['CTC_GIF'], 'r')
	cfg['CTCGIF'] = locf.read(CTC_GIF_SIZE)
	locf.close()
	del cfg['CTC_GIF']

	tmpval = os.stat(cfg['ERROR_HTML_FILE'])
	ERROR_HTML_SIZE = tmpval[6]
	locf = open(cfg['ERROR_HTML_FILE'], 'r')
	cfg['ERR_MSG'] = locf.read(ERROR_HTML_SIZE)
	locf.close()
	del cfg['ERROR_HTML_FILE']

	cfg['ADV_RET_BUFF'] = """HTTP/1.1 200 OK
Server: Cut The Crap
Content-Length: """ + `RETURN_GIF_SIZE` + """
Proxy-Connection: close
Content-Type: image/gif

"""
	cfg['CTCGIF_RET_BUFF'] = """HTTP/1.1 200 OK
Server: Cut The Crap
Content-Length: """ + `CTC_GIF_SIZE` + """
Proxy-Connection: close
Content-Type: image/gif

"""

	del cfg['ZAPLET_DIR']

	return cfg


# Another intermediate step before parsing the configuration file
def get_conf(conf_file):

	cfg = startup_values()

	if conf_file != None:
		conf_obj = read_conf.READ_CONF(sys.argv[1])
		for key, val in conf_obj.parse_cfg().items():
			cfg[key] = val
	
	cfg['VERSION'] = '0.3.0'
	cfg['VERSION_NAME'] = 'Parthenon'
	cfg['BUFF_SIZE'] = 8192
	cfg['Z_ENGINE'] = zaplet_engine.zaplet_engine(cfg['ZAPLET_DIR'])

	cfg = cfg_convert(cfg)

	return cfg


def term_handle():
	if posixpath.exists("/var/run/ctc.py.pid"):
		try:
			os.unlink("/var/run/ctc.py.pid")
		except OSError, msg:
			print "/var/run/ctc.py.pid: " + msg[1]
	
	sys.exit(0)


